@@ -13,7 +13,7 @@ SCALE_API_BASE_URL_V1 = "https://api.scale.com/v1"
 HTTP_TOTAL_RETRIES = 3  # Number of total retries
 HTTP_RETRY_BACKOFF_FACTOR = 2  # Wait 1, 2, 4 seconds between retries
 HTTP_STATUS_FORCE_LIST = [408, 429] + list(range(500, 531))
-HTTP_RETRY_ALLOWED_METHODS = frozenset({"GET", "POST"})
+HTTP_RETRY_ALLOWED_METHODS = frozenset({"GET", "POST", "DELETE"})
 
 
 class Api:
@@ -134,6 +134,12 @@ class Api:
             data=data,
         )
 
+    def delete_request(self, endpoint, params=None):
+        """Generic DELETE Request Wrapper"""
+        return self._api_request(
+            "DELETE", endpoint, headers=self._headers, auth=self._auth, params=params
+        )
+
     @staticmethod
     def _generate_useragent(extension: str = None) -> str:
         """Generates UserAgent parameter with module, Python
